import setuptools
 
setuptools.setup(
    name="requests-prettyprint",
    description="Python Requests Pretty Printer",
    version="0.0.2",
    author="Andrew Tappert",
    author_email="andrew.tappert@fireeye.com",
    url="https://github.com/atappert-fe/requests-prettyprint",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)
